/* libwcs headers don't have these declarations */

extern char* eqstrn(double, double);
extern void wcsrotset(struct WorldCoor*);
extern int wcspos(double, double, struct WorldCoor*, double*, double*);
extern int wcspix(double, double, struct WorldCoor*, double*, double*);
extern void fk524(double*, double*);
/*extern void fk524e(double*, double*, double);*/
extern void fk524m(double*, double*, double*, double*);
extern void fk524pv(double*, double*, double*, double*, double*, double*);
extern void fk425(double*, double*);
/*extern void fk425e(double*, double*, double);*/
extern void fk425m(double*, double*, double*, double*);
extern void fk425pv(double*, double*, double*, double*, double*, double*);
extern void fk42gal(double*, double*);
extern void gal2fk4(double*, double*);
extern void fk52gal(double*, double*);
extern void gal2fk5(double*, double*);
extern void fk42ecl(double*, double*, double);
extern void fk52ecl(double*, double*, double);
extern void ecl2fk4(double*, double*, double);
extern void ecl2fk5(double*, double*, double);
extern void v2s3(double*, double*, double*, double*);
extern void s2v3(double, double, double, double*);
extern void fk4prec(double, double, double*, double*);
extern void fk5prec(double, double, double*, double*);
extern void mprecfk4(double, double, double**);
extern void mprecfk5(double, double, double**);
extern int dsspos(double, double, struct WorldCoor*, double*, double*);
extern int dsspix(double, double, struct WorldCoor*, double*, double*);
extern int platepos(double, double, struct WorldCoor*, double*, double*);
extern int platepix(double, double, struct WorldCoor*, double*, double*);
extern int SetPlate(struct WorldCoor*, int, int, double*);
extern int GetPlate(struct WorldCoor*, int*, int*, double*);
extern int GetPlate(struct WorldCoor*, int*, int*, double*);
extern void SetFITSPlate(char*, struct WorldCoor*);
/*extern int tnxinit(char*, struct WorldCoor*);*/
extern int tnxpos(double, double, struct WorldCoor*, double*, double*);
extern int tnxpix(double, double, struct WorldCoor*, double*, double*);
extern void tnxclose(struct WorldCoor*);
extern int tnxpset(struct WorldCoor*, int, int, int, double*);
extern int worldpos(double, double, struct WorldCoor*, double*, double*);
extern int worldpix(double, double, struct WorldCoor*, double*, double*);
extern struct StarCat* actopen(int);
extern void actclose(struct StarCat*);
extern int usaread(double, double, double, double, double, int, int, double, double, double, double, int, int, double*, double*, double*, double**, double*, int*, int);
extern int usarnum(int, int, double, double, double*, double*, double*, double**, int*, int);
extern double hjd2jd(double, double, double, int);
extern double jd2hjd(double, double, double, int);
extern double mhjd2mjd(double, double, double, int);
extern double mjd2mhjd(double, double, double, int);
extern void mjd2doy(double, int*, double*);
extern double epb2ep(double);
extern double epj2ep(double);
extern int jd2tsi(double);
extern time_t jd2tsu(double);
extern void tsi2dt(int, double*, double*);
extern int FindStars(char*, char*, double**, double**, double**, int**, int, int);
extern void setparm(char*);
extern int SetWCSFITS(char*, char*, char*, char*, int);
extern void settolerance(double);
extern void setirafout(void);
extern void setmatch(char*);
extern void setreflim(double, double);
extern void setclass(int);
extern void setfitwcs(int);
extern void setfitplate(int);
extern void setplate(int);
extern void setminstars(int);
extern void setnofit(void);
extern void setfrac(double);
extern void setimfrac(double);
extern void setmaxcat(int);
extern void setiterate(int);
extern void setnfiterate(int);
extern void setiteratet(int);
extern void setrecenter(int);
extern void setsortmag(int);
extern void setmagfit(void);
extern int StarMatch(int, double*, double*, int, int, double*, double*, double*, int*, double*, double*, double, struct WorldCoor*, int);
extern int ParamFit(int);
extern int NParamFit(int);
extern int ReadMatch(char*, double**, double**, double**, double**, int);
extern void WCSMatch(int, double*, double*, double*, double*, int);
extern int FitMatch(int, double*, double*, double*, double*, struct WorldCoor*, int);
extern void setresid_refine(int);
extern int getresid_refine(void);
extern void setnfit(int);
extern int getnfit(void);
extern int iscdfit(void);
extern void setminmatch(int);
extern void setminbin(int);
extern void setnitmax(int);

